PyXMake Developer Guide: PyXMake.Tools Namespace Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Namespaces
PyXMake.Tools Namespace Reference

Module containing basic functionalities defined for convenience. More...

## Namespaces
namespace | ErrorHandling
| Error handling module.
namespace | Utility
| Module of basic functions.

## Detailed Description

Module containing basic functionalities defined for convenience.

    Contains some fundamental utility functions used within PyXMake.

    @note: PyXMake module
    Created on 20.03.2018

    @version:  1.0
    ----------------------------------------------------------------------------------------------
    @requires:
          -

    @change:
          -

    @author: garb_ma                                                     [DLR-FA,STM Braunschweig]
    ----------------------------------------------------------------------------------------------

Author
  Marc Garbade

Date
  20.03.2018

Notes/Changes
  - Added documentation // mg 29.03.2018